@@ -438,6 +438,9 @@ struct tp_dispatch {
 	} tap;
 
 	struct {
+		struct libinput_device_config_dwtp config;
+		bool dwtp_enabled;
+
 		int32_t right_edge;		/* in device coordinates */
 		int32_t left_edge;		/* in device coordinates */
 		int32_t upper_edge;		/* in device coordinates */
