@@ -191,14 +191,19 @@ wheel_flush_scroll(struct fallback_dispatch *dispatch,
 	 * trackstick data via REL_WHEEL. Normalize it like normal x/y coordinates.
 	 */
 	if (device->model_flags & EVDEV_MODEL_LENOVO_SCROLLPOINT) {
-		struct normalized_coords unaccel = { 0.0, 0.0 };
-
-		dispatch->wheel.lo_res.y *= -1;
-		fallback_normalize_delta(device, &dispatch->wheel.lo_res, &unaccel);
+		const struct device_float_coords raw = {
+			.x = dispatch->wheel.lo_res.x,
+			.y = dispatch->wheel.lo_res.y * -1,
+		};
+		const struct normalized_coords normalized =
+				filter_dispatch_constant(device->pointer.filter,
+						         &raw,
+							 device,
+							 time);
 		evdev_post_scroll(device,
 				  time,
 				  LIBINPUT_POINTER_AXIS_SOURCE_CONTINUOUS,
-				  &unaccel);
+				  &normalized);
 		dispatch->wheel.hi_res.x = 0;
 		dispatch->wheel.hi_res.y = 0;
 		dispatch->wheel.lo_res.x = 0;
