@@ -306,6 +306,17 @@ struct libinput_device_config_dwt {
 			 struct libinput_device *device);
 };
 
+struct libinput_device_config_dwtp {
+	int (*is_available)(struct libinput_device *device);
+	enum libinput_config_status (*set_enabled)(
+			 struct libinput_device *device,
+			 enum libinput_config_dwtp_state enable);
+	enum libinput_config_dwtp_state (*get_enabled)(
+			 struct libinput_device *device);
+	enum libinput_config_dwtp_state (*get_default_enabled)(
+			 struct libinput_device *device);
+};
+
 struct libinput_device_config_rotation {
 	int (*is_available)(struct libinput_device *device);
 	enum libinput_config_status (*set_angle)(
@@ -333,6 +344,7 @@ struct libinput_device_config {
 	struct libinput_device_config_click_method *click_method;
 	struct libinput_device_config_middle_emulation *middle_emulation;
 	struct libinput_device_config_dwt *dwt;
+	struct libinput_device_config_dwtp *dwtp;
 	struct libinput_device_config_rotation *rotation;
 	struct libinput_device_config_gesture *gesture;
 };
@@ -395,10 +407,8 @@ struct libinput_tablet_tool {
 	void *user_data;
 
 	struct {
-		/* The pressure threshold assumes a pressure_offset of 0 */
-		struct threshold threshold;
-		/* pressure_offset includes axis->minimum */
-		int offset;
+		struct threshold threshold; /* in device coordinates */
+		int offset; /* in device coordinates */
 		bool has_offset;
 	} pressure;
 };
