@@ -48,7 +48,7 @@
 
 #include "shared.h"
 
-#ifdef GDK_WINDOWING_WAYLAND
+#if HAVE_GTK_WAYLAND
 	#include <wayland-client.h>
 	#include "pointer-constraints-unstable-v1-client-protocol.h"
 	#if HAVE_GTK4
@@ -58,7 +58,7 @@
 	#endif
 #endif
 
-#ifdef GDK_WINDOWING_X11
+#if HAVE_GTK_X11
 	#include <X11/X.h>
 	#include <X11/Xlib.h>
 	#if HAVE_GTK4
@@ -120,7 +120,7 @@ struct window {
 	struct {
 		bool locked;
 
-#ifdef GDK_WINDOWING_WAYLAND
+#if HAVE_GTK_WAYLAND
 		struct zwp_pointer_constraints_v1 *wayland_pointer_constraints;
 		struct zwp_locked_pointer_v1 *wayland_locked_pointer;
 #endif
@@ -207,7 +207,7 @@ struct window {
 	struct libinput_device *devices[50];
 };
 
-#ifdef GDK_WINDOWING_WAYLAND
+#if HAVE_GTK_WAYLAND
 static void
 wayland_registry_global(void *data,
 			struct wl_registry *registry,
@@ -297,9 +297,9 @@ backend_is_wayland(void)
 {
 	return GDK_IS_WAYLAND_DISPLAY(gdk_display_get_default());
 }
-#endif /* GDK_WINDOWING_WAYLAND */
+#endif /* HAVE_GTK_WAYLAND */
 
-#ifdef GDK_WINDOWING_X11
+#if HAVE_GTK_X11
 static bool
 x_lock_pointer(struct window *w)
 {
@@ -342,19 +342,20 @@ backend_is_x11(void)
 {
 	return GDK_IS_X11_DISPLAY(gdk_display_get_default());
 }
-#endif /* GDK_WINDOWING_X11 */
+#endif /* HAVE_GTK_X11 */
 
 static bool
 window_lock_pointer(struct window *w)
 {
-	w->lock_pointer.locked = false;
+	if (w->lock_pointer.locked)
+		return true;
 
-#ifdef GDK_WINDOWING_WAYLAND
+#if HAVE_GTK_WAYLAND
 	if (backend_is_wayland())
 		w->lock_pointer.locked = wayland_lock_pointer(w);
 #endif
 
-#ifdef GDK_WINDOWING_X11
+#if HAVE_GTK_X11
 	if (backend_is_x11())
 		w->lock_pointer.locked = x_lock_pointer(w);
 #endif
@@ -370,12 +371,12 @@ window_unlock_pointer(struct window *w)
 
 	w->lock_pointer.locked = false;
 
-#ifdef GDK_WINDOWING_WAYLAND
+#if HAVE_GTK_WAYLAND
 	if (backend_is_wayland())
 		wayland_unlock_pointer(w);
 #endif
 
-#ifdef GDK_WINDOWING_X11
+#if HAVE_GTK_X11
 	if (backend_is_x11())
 		x_unlock_pointer(w);
 #endif
@@ -603,8 +604,6 @@ draw_scrollbars(struct window *w, cairo_t *cr)
 static inline void
 draw_touchpoints(struct window *w, cairo_t *cr)
 {
-	struct touch *t;
-
 	cairo_save(cr);
 	ARRAY_FOR_EACH(w->touches, t) {
 		if (t->state == TOUCH_ACTIVE)
@@ -1155,7 +1154,6 @@ window_init(struct window *w)
 static void
 window_cleanup(struct window *w)
 {
-	struct libinput_device **dev;
 	ARRAY_FOR_EACH(w->devices, dev) {
 		if (*dev)
 			libinput_device_unref(*dev);
@@ -1165,8 +1163,6 @@ window_cleanup(struct window *w)
 static void
 change_ptraccel(struct window *w, double amount)
 {
-	struct libinput_device **dev;
-
 	ARRAY_FOR_EACH(w->devices, dev) {
 		double speed;
 		enum libinput_config_status status;
@@ -1341,7 +1337,6 @@ static void
 handle_event_device_notify(struct libinput_event *ev)
 {
 	struct libinput_device *dev = libinput_event_get_device(ev);
-	struct libinput_device **device;
 	struct libinput *li;
 	struct window *w;
 	const char *type;
